#AutoLIST
ListOrString = None
def _first_value(data: ListOrString, m) -> str:
    if isinstance(data, list):
        return list(data[m])
    else:
        return list(data)


ptslist = []
def autocorrect_list(string : str, li : list):
    listlen = len(li)
    strlen = len(string)
    for j in range(0, listlen):
        pts = 0
        listring = li[listlen-1]
        for i in range(0, listlen):
            a = _first_value(li, j)[i]
            b = _first_value(string, j)[i]
            if a == b:
                pts += 2
            else:
                pts -= 1
        ptslist.append(pts)
    maxindex = ptslist.index(max(ptslist))
    no = li[maxindex]
    return no



from setuptools import setup, find_packages

with open("README.md", "r", encoding ="utf8") as f:
    long_description = f.read()

setup(
    name="autolist",
    version="0.0.4",
    author="Abel Roy",
    author_email="abelroi007@gmail.com",
    description="Auto-Corrects mistyped words by checking them with the list of given correct words",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/AbelR007/Autolist",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
